#ifndef ROLES_H
#define ROLES_H

enum DataRole
{
    IdRole = Qt::UserRole + 1,
    NameRole,
    TypeRole,
    ColorRole,
    VisibilityRole,
    HeadingRole,
    DetailsRole,
    DateRole,
    PathRole,
    ComponentRole,
    TodoRole,
    JournalRole,
    EventCountRole,
    TodoCountRole,
    JournalCountRole
};

#endif // ROLES_H
